/* EventKeymap.ino
 *
 * Mintapélda a billentyűmátrix által kiváltott események kezelésére.
 * Egy LED-et kapcsolgatunk ki/be a # gombbal, s villogtatjuk a * gombbal.
 * A Keypad programkönyvtár eredeti mintaprogramját módosítottuk, hogy
 * 4x4-es billentyűműtrixot kezeljen, s a lábkiosztást is módosítottuk.
 *
 * Hardver követelmények:
 * - Arduino kártya
 * - 4x4-es billentyűmátrix a D2-D9 kivezetésekre kötve
 * - Egy LED a D13 kivezetésre kötve (ez az Arduino kártyákon már megtalálható)
 */
#include <Keypad.h>

const byte ROWS = 4;                                  //nyomógomb sorok száma
const byte COLS = 4;                                  //nyomógomb oszlopok száma
char keys[ROWS][COLS] = {                             //Billentyű kódok
    {'1','2','3','A'},
    {'4','5','6','B'},
    {'7','8','9','C'},
    {'*','0','#','D'}};

byte rowPins[ROWS] = {2,3,4,5};                       //lábkiosztás a sorvezetékekhez 
byte colPins[COLS] = {6,7,8,9};                       //lábkiosztás az oszlopvezetékekhez

//--- A billentyűzet objektumosztály példányosítása --------------------
Keypad keypad = Keypad( makeKeymap(keys), rowPins, colPins, ROWS, COLS );
byte ledPin = 13;                                     // D13-ra van köteve a LED

boolean blink = false;                                // villogtatás jelzője
boolean ledPin_state;                                 // LED állapot tárolója

void setup(){
    Serial.begin(9600);                               // soros port inicializálása
    pinMode(ledPin, OUTPUT);                          // ledpin legyen digitális kimenet
    digitalWrite(ledPin, HIGH);                       // bekapcsoljuk a LED-et
    ledPin_state = digitalRead(ledPin);               // eltároljuk a LED kiinduló állapotát
    keypad.addEventListener(keypadEvent);             // eseménykiszolgálót rendelünk az eszközhöz
}

void loop(){
    char key = keypad.getKey();                       // gomblenyomás figyelése
    if (key) {
        Serial.println(key);                          // ha volt gomblenyomás, akkor kiíratjuk
    }
    if (blink){                                       // LED villogtatás végrehajtása, ha kell:
        digitalWrite(ledPin,!digitalRead(ledPin));    // LED állapotváltás
        delay(100);                                   // 100 ms várakozás
    }
}

//--- Billentyűzet eseményeinek feldolgozása ---------
void keypadEvent(KeypadEvent key){
    switch (keypad.getState()){                        // az esemény vizsgálata
    case PRESSED:                                      // ha gomblenyomás történt
        if (key == '#') {                              // Ha ez a # gomb, akkor:
            digitalWrite(ledPin,!digitalRead(ledPin)); // LED-et ellenkező állapotba billentjük
            ledPin_state = digitalRead(ledPin);        // és megjegyezzük a LED új állapotát
        }
        break;

    case RELEASED:                                     // ha felengedés történt, 
        if (key == '*') {                              // és ez a * gomb volt, akkor:
            digitalWrite(ledPin,ledPin_state);         // a LED eredeti állapotát visszaállítjuk
            blink = false;                             // és a villogtatást letiltjuk 
        }
        break;

    case HOLD:                                         // ha lenyomva tartás történt,
        if (key == '*') {                              // és ez a * gomb, akkor:
            blink = true;                              // a villogtatást engedélyezzük
        }
        break;
    }
}
