
/* dipswitch
 *
 * A D2 és D3 bementre kötött kapcsolók állása szerint négy fokozatban szabályozzuk 
 * a LED fényerejét. A LED fényerejét a D6 kimenet, mint PWM csatorna, kitöltési 
 * tényezőjének változtatásával szabályozzuk. A kitöltést nem lineárisan, hanem 
 * mértani haladvány szerint csökkentjük/növeljük, mivel a szemünk sem lineárisan 
 * érzékel (a kétszer nagyobb fényteljesítményt nem érezzük kétszer fényesebbnek). 
 * Számolgatás helyett az előre kiszámolt értékeket egy tömbben tároljuk.
 *
 * Hardware követelmények:
 * - Arduino kártya
 * - két kapcsoló GND és a D2, illetve D3 kivezetések közé kötve
 * - LED és egy előtétellenállás (100 - 1000 Ohm) a D6 kimenet és GND közé kötve
 *
 *  _________   LED  470R 
 *    A   D6 |--|>|--/\/\/\---+
 *    R      |   K2           |
 *    D   D3 |----/ ----------+
 *    U      |   K1           |
 *    I   D2 |----/ ----------+  
 *    N      |                |
 *    O      |               GND
 */ 


uint8_t duty[] = {4,16,64,255 };  //exponenciálisan növekvő kitöltés

void setup() {
  pinMode(2, INPUT_PULLUP);      //digitális bemenet felhúzással
  pinMode(3, INPUT_PULLUP);      //digitális bemenet felhúzással
  analogWrite(6,duty[0]);        //Kezdeti fényerő
}

void loop() {
  int keys = digitalRead(2) +
           2*digitalRead(3);     //kapcsolók állásának beolvasása
  analogWrite(6,duty[keys]);     //LED fényerő beállítása
  delay(100);                    //Várunk egy kicsit... 
}

